/*
 * Copyright 2019-present MongoDB, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef TEST_MONGOCRYPT_ASSERT_MATCH_BSON_H
#define TEST_MONGOCRYPT_ASSERT_MATCH_BSON_H

#include <bson/bson.h>

/* Copied from libmongoc. */
void _assert_match_bson(const bson_t *doc, const bson_t *pattern);

#endif /* TEST_MONGOCRYPT_ASSERT_MATCH_BSON_H */
